@@ -19,47 +19,12 @@ from collections import deque
 import warnings
 from typing import Any
 
-"""
-Defines data classes for structure of settings file
-NOTE this was removed as dill and cattr were unstable / unreliable in different versions. Sacrificed consistency compfort for stability here...
-
-@dataclasses.dataclass
-class CommodityDetails:
-    name: str  # name of the commodity
-    price: str  # name of the price index
-    value: float = 1.0  # initial stock value of price index
-    depreciation: float = 0.0  # depreciation rate
-    description: str = "No description"  # description of this commodity
-    unit: str = "unknown unit"
-
-
-@dataclasses.dataclass
-class MetaInfo:
-    author: str = "Unknown Author"
-    date: str = "Unknown Date"
-    comment: str = ""
-
-
-@dataclasses.dataclass
-class HyperParameter:
-    name: str
-    value: Any = None
-    description: str = "no description"
-
-
-@dataclasses.dataclass
-class Config:
-    metainfo: MetaInfo
-    params: Sequence[CommodityDetails]
-    hyperparams: Sequence[HyperParameter] = deque()
-
-"""
-
 
 class Settings(Singleton):
     """
     This is a settings class that serves as a central data structure to store hyperparameters, commodity names, depreciation rates etc.
     It also includes a section with metadata on author etc...
+    
     """
 
     def __init__(self):
@@ -118,6 +83,7 @@ class Settings(Singleton):
 
         :param data: either str, i.e. a string containing the data, or path/str, i.e. file name to read from
         :param isfile: boolean switch. If False, a string has to be passed.
+
         ** Example **
 
         "filename.yml" File:
@@ -322,8 +288,6 @@ class Settings(Singleton):
     def get_hyperparameter(self, name):
         """
         get the value of a hyperparameter by its name.
-        WARNING this is expensive (string key lookup) -> it is recommended to look this up only once and then store it as an attribute in an agent's instance.
-        #^TODO check if this is actually expensive
 
         :param name: the name of the hyper-parameter to filter for
         """
