@@ -59,22 +59,31 @@ class World(Singleton):
         """
         return self.agent_types # return list directly
 
-    def link(self):
+    def link(self,verbose=False):
         """
         Calls the 'link' fun in all the agents to inter-link them in the world
         """
         pool_a = list(self.helper_registry.values())
         pool_b = list(self.agent_registry.values())
 
+        #if verbose:
+        #    print("[WORLD] LINK ... %i agents" % (len(pool_a)+len(pool_b)))
+
         for agent_list in pool_a + pool_b:
             for agent in list(set(agent_list)):
                 if hasattr(agent,"link"):
                     if callable(getattr(agent, "link")):
                         agent.link()
+                        if verbose:
+                            print("[WORLD] LINK", agent )
                     else:
-                        warnings.warn("WORLD LINK: Link attr of %s is not callable. Skipping..." % str(agent))
+                        if verbose:
+                            warnings.warn("[WORLD] LINK: Link attr of %s is not callable. Skipping..." % str(agent))
                 else:
-                    pass # NOTE it is ok if it has no link attr
+                    if verbose:
+                        warnings.warn("[WORLD] LINK: %s has no link attr." % agent)
+
+                    # NOTE it is ok if it has no link attr
 
     def reset(self,verbose=False):
         """
