@@ -67,8 +67,11 @@ class BalanceSheet:
     @classmethod
     def change_tolerance(cls, tol:float, rel_tol:float):
         """
-        change the tolerance by which the balace is allowed to diverge
-        This will set the new values globally.
+        Change the tolerance by which the balace is allowed to diverge
+        This will set the new values globally. The tolerance is checked in a two-step process:
+        Frist, the absolute tolerance violation is checked, i.e. if any balance sheet side sums up to more or less than the other side.
+        If the absolute tolerance is violated, an error is thrown if also the relative tolerance is exceeded. The latter is the second step of the checking process.
+        If the relative deviation is violated but the absolute level is not exceeded, no error wil be thrown.
 
         :param tol: new absolute tolerance
         :param rel_tol: relative tolerance (relative devaition from total assets)
@@ -497,9 +500,27 @@ class BalanceSheet:
         return return_val
 
 
-    def plot(self,show_labels=True):
+    def plot(self,show_labels=True,cols_assets=None, cols_liabs=None,cols_eq=None,show_legend=True,
+                  fname=None,ax=None):
         """
         creates a matplotlib plot of the balance sheet
+
+        :param show_labels: show labels (numbers) above the bars
+        :param show_legend: (True) show a legend with the balance sheet entries
+
+        By default, assets are red, equity is blue and liabilites are green
+        but custom colors can be given
+
+        :param cols_assets: (None) list of mpl colors for assets
+        :param cols_liabs: (None) list of mpl colors for liabilities
+        :param cols_eq: (None) list of mpl colors for equity
+
+        if you want to save to file instead of showing as plot window, specify a fname
+        :param fname: if None (default) is given, plot will be shown directly. If fname is given, plot will be saved to a file
+
+
+        if you want to redirect the plot to a certain axis, you can enter the axis via the parameter ax
+        :param ax: axis to plot on. setting this parameter different from None will make 'fname' ineffective
         """
         import matplotlib.pyplot as plt
         import matplotlib.patches as mpatches
@@ -513,9 +534,21 @@ class BalanceSheet:
         liabilities = []
 
         colors = []
-        greens = [ "lightgreen", "honeydew","seagreen", "darkgreen", "darkslategray"]
-        blues = ["lightsteelblue", "lavender", "powderblue", "steelblue", "royalblue", "blue"]
-        reds = ["salmon", "indianred", "rosybrown", "orangered", "red", "indianred"]
+
+        if cols_liabs is None:
+            greens = [ "lightgreen", "honeydew","seagreen", "darkgreen", "darkslategray"]
+        else:
+            greens = cols_liabs
+
+        if cols_eq is None:
+            blues = ["lightsteelblue", "lavender", "powderblue", "steelblue", "royalblue", "blue"]
+        else:
+            blues = cols_eq
+
+        if cols_assets is None:
+            reds = ["salmon", "indianred", "rosybrown", "orangered", "red", "indianred"]
+        else:
+            reds = cols_assets
 
         greens.reverse()
         blues.reverse()
@@ -565,6 +598,8 @@ class BalanceSheet:
                     lia.append([key, 0.0])
 
         # construct data for plotting
+        # by default, assets are red, equity is blue and liabilites are green
+        k = 0
         for a in assets:
 
             key = a[0]
@@ -574,13 +609,17 @@ class BalanceSheet:
                 data["Assets"].append(val)
                 data["Liabilities & Equity"].append(0.0)
 
-                col = reds.pop()
+                col = reds[k%len(reds)]
                 colors.append(col) # (col, "black"))
                 red_patches.append(mpatches.Patch(color=col, label=key))
 
                 labels[i] = key
                 i += 1
 
+            k+=1
+
+
+        k = 0
         for e in equi:
             key = e[0]
             val = e[1]
@@ -589,13 +628,16 @@ class BalanceSheet:
                 data["Assets"].append(0.0)
                 data["Liabilities & Equity"].append(val)
 
-                col = blues.pop()
+                col = blues[k%len(blues)]
                 colors.append(col) # ("black", col))
                 blue_patches.append(mpatches.Patch(color=col, label=key))
 
                 labels[i] = key
                 i += 1
 
+            k+=1
+
+        k = 0
         for l in lia:
 
             key = l[0]
@@ -605,13 +647,15 @@ class BalanceSheet:
                 data["Assets"].append(0.0)
                 data["Liabilities & Equity"].append(val)
 
-                col = greens.pop()
+                col = greens[k%len(greens)]
                 colors.append(col) #("black", col))
                 green_patches.append(mpatches.Patch(color=col, label=key))
 
                 labels[i] = key
                 i += 1
 
+            k+=1
+
         # create customized patche for the legend
         legend_patches = red_patches + blue_patches + green_patches
 
@@ -621,15 +665,27 @@ class BalanceSheet:
         # print("PLOT\n",df)
         # print("colors",colors)
 
-        fig = matplotlib_barplot(df.T, xlabel="", ylabel="", color=colors, title=title, stacked=True, show_labels=show_labels,fmt="{0:.2f}",
-                                legend="off", size=(4, 4), show=False)
 
-        plt.gca().legend(handles=legend_patches, bbox_to_anchor=(1.3, 1),framealpha=0.0)
+
+        fig = matplotlib_barplot(df.T, xlabel="", ylabel="", color=colors, title=title, stacked=True, show_labels=show_labels,fmt="{0:.2f}",
+                                legend="off", size=(4, 4), show=False,ax=ax)
+
+        if ax is None:
+            ax = plt.gca()
+
+        ax.legend(handles=legend_patches, bbox_to_anchor=(1.3, 1),framealpha=0.0)
 
         plt.axis("off")
         plt.tight_layout()
-        plt.show()
 
+        if ax is None:
+            if fname is None:
+                plt.show()
+            else:
+                plt.savefig(fname)
+                plt.close()
+
+        return ax 
 
     @classmethod
     def plot_list(cls,list_of_balance_sheets,dt=1,xlabel=None,ylabel=None,title=None,show_liabilities=True,show=True):
