@@ -4,26 +4,19 @@ Mamba interpreter ver 0.2
 
 import re
 
-
-
 def process_line(line,r=0):
     # recursion dpeth
 
-
     # transaction definitions
     for match in re.finditer(r'\<\~\~\>\s+[\(\)A-Za-z0-9,\@\s\_]+',line):
         start, end = match.span()
         mstr = match.group(0)
 
-
         try:
-
             line = line.replace("<~~>", '').replace(" ", '')
-
         except:
             pass
 
-
     # replace agent references
     for match in re.finditer(r'\@[A-Za-z0-9_]+',line):
         start, end = match.span()
@@ -90,8 +83,11 @@ from .transactions import *
     r = 0 # recursion depth for nested statements
 
     line_idx = 0
-    for line in codelines:
 
+    commend_mode = False # current line is a comment?
+
+    for line in codelines:
+        line = line.rstrip()
         if line.startswith("$[AGENT]"):  # agent definition starts
 
             try:
@@ -118,6 +114,8 @@ class %s(%s):
             except:
 
                 return "ERROR please specify name after $[AGENT]",mydict
+
+        
         elif line.startswith("$[CLASS]"):  # agent definition starts
 
             try:
