@@ -46,21 +46,21 @@ class ThemeManager:
         # default values
         self.dark_theme = [QtGui.QColor(50, 50, 50 , 255),
                            QtGui.QColor(120, 120, 120, 255),
-                           QtGui.QColor(255, 0, 55 , 120), # transaction lines
-                            QtGui.QColor(255, 255, 255 , 255),
-                            QtGui.QColor(255, 255, 255, 255),
+                           QtGui.QColor(220,220,220, 120), # transaction lines
+                            QtGui.QColor(177,177,177 , 255),
+                            QtGui.QColor(175,175,175, 255),
                             QtGui.QColor(180, 180, 180, 255),
-                            QtGui.QColor(255, 0, 55 , 255), # box labels
+                            QtGui.QColor(72,72,72 , 255), # box labels
                             QtGui.QColor(120,120,120,80) # background
                            ]
 
         self.bright_theme =[QtGui.QColor(50, 50, 50 , 255),
                            QtGui.QColor(20, 20, 20, 255),
-                           QtGui.QColor(50, 50, 50 , 80), # transaction lines
-                            QtGui.QColor(80, 80, 80 , 255),
-                            QtGui.QColor(255, 2, 2, 255),
-                            QtGui.QColor(45, 44, 255, 255),
-                            QtGui.QColor(50, 50, 50 , 255), # box labels
+                           QtGui.QColor(81, 81, 81 , 80), # transaction lines
+                            QtGui.QColor(221,221,221, 200),
+                            QtGui.QColor(255, 44, 47, 255),
+                            QtGui.QColor(255, 44, 47, 255),
+                            QtGui.QColor(47, 47,47 , 255), # box labels
                             QtGui.QColor(80,80,80,100) # background
                            ]
 
@@ -77,40 +77,73 @@ class ThemeManager:
             filename = QFileDialog.getOpenFileName(self.parent, 'Open file',os.getcwd(), "Attune Theme Files (*.sfctheme)")[0]
 
         if filename is not None and filename != "":
+
+            success = False
             try:
                 with open(filename,"rb") as file:
                     theme = pickle.load(file)
                     self.colors[self.theme] = theme
                     self.restore_buttons()
+                success = True
             except:
-                self.parent.notify("Could not open theme.", title="Error")
+                pass
+
+            if not success:
+                try: # try with relative path ?
+                    filename = os.path.split(filename)[1]
+                    foldername = os.path.dirname(self.parent.current_file)
+                    filename = os.path.join(foldername,filename)
+                    with open(filename,"rb") as file:
+                        theme = pickle.load(file)
+                        self.colors[self.theme] = theme
+                        self.restore_buttons()
+                    success = True
+                except:
+                    pass
+
+            if not success:
+                self.parent.notify("Could not open theme from %s" % filename , title="Error")
 
     def save_colors(self,filename=None):
-        btn_table = {
-                1: self.parent.bc1,
-                2: self.parent.bc2,
-                3: self.parent.bc3,
-                4: self.parent.bc4,
-                5: self.parent.bc5,
-                6: self.parent.bc6,
-                7: self.parent.bc7,
-                8: self.parent.bc8,
-            }
-
-        ssheets = []
-        for i,color in enumerate(self.bright_theme):
-            ssheets.append(btn_table[i+1].palette().button().color())
-
-        print(ssheets)
+        # save the colortheme to reative path
 
         if filename is None:
-            filename = QFileDialog.getSaveFileName(self.parent, 'Save file',os.getcwd(), "Attune Theme Files (*.sfctheme)")[0]
+            return
+
+        try:
+            # get the path of the main file
+            foldername = os.path.dirname(self.parent.current_file)
+
+            # join path to save under same folder as main file
+            filename = os.path.join(foldername,filename)
+
+            btn_table = {
+                    1: self.parent.bc1,
+                    2: self.parent.bc2,
+                    3: self.parent.bc3,
+                    4: self.parent.bc4,
+                    5: self.parent.bc5,
+                    6: self.parent.bc6,
+                    7: self.parent.bc7,
+                    8: self.parent.bc8,
+                }
+
+            ssheets = []
+            for i,color in enumerate(self.bright_theme):
+                ssheets.append(btn_table[i+1].palette().button().color())
+
+            print(ssheets)
+
+            if filename is None:
+                filename = QFileDialog.getSaveFileName(self.parent, 'Save file',os.getcwd(), "Attune Theme Files (*.sfctheme)")[0]
 
 
-        if filename is not None and filename != "":
-            with open(filename,"wb") as file:
-                pickle.dump(ssheets,file)
+            if filename is not None and filename != "":
+                with open(filename,"wb") as file:
+                    pickle.dump(ssheets,file)
 
+        except:
+            self.parent.notify("An error occurred.",title="Error")
 
     def get_color(self,category):
         """
@@ -127,7 +160,7 @@ class ThemeManager:
         # style of notifiaction window
 
         notification_styles = {
-            "dark": "QLabel{color:black}",
+            "dark": "QLabel{color:white}",
             "bright": "QLabel{color:black}"
         }
 
