@@ -68,6 +68,7 @@ class SettingsEditor(QtWidgets.QDialog):
         self.searchEdit.textChanged.connect(self.find_param)
         self.tableView.doubleClicked.connect(self.scroll_to)
         # self.okButton.pressed.connect(self.send_data)
+       
 
         self.update_valid()
         self.rebuild_table()
@@ -170,10 +171,10 @@ class SettingsEditor(QtWidgets.QDialog):
 
         if valid:
             self.validLabel.setText("valid")
-            self.validLabel.setStyleSheet("background-color: lightgreen")
+            self.validLabel.setStyleSheet("background-color: lightgreen; color: black;")
         else:
             self.validLabel.setText("invalid")
-            self.validLabel.setStyleSheet("background-color: yellow")
+            self.validLabel.setStyleSheet("background-color: yellow; color: black;")
 
         self.update()
 
