@@ -25,14 +25,24 @@ def add_value_labels(ax, spacing=.9, fmt="{0:d}", stacked=False, legend="best"):
         ax (matplotlib.axes.Axes): The matplotlib object containing the axes
             of the plot to annotate.
         spacing (int): The distance between the labels and the bars.
-
     """
 
+    my_figure = ax.get_figure()
+    L = ax.get_ylim()[1] - ax.get_ylim()[0]
+    min_height = L*0.05
+
+    print("min_heigth", min_height)
+
     # For each bar: Place a label
     for rect in ax.patches:
         # Get X and Y placement of label from rect.
-        y_value = rect.get_y() + rect.get_height() * 1.01
-        x_value = rect.get_x() + rect.get_width() * 0.01
+
+        if rect.get_height() <= min_height:
+            continue
+        print("rect height", rect.get_height())
+
+        y_value = rect.get_y() + rect.get_height() * 0.51
+        x_value = rect.get_x() + rect.get_width() * 0.03
 
         # print("yvalue",x_value,y_value)
         # Number of points between bar and label. Change to your liking.
@@ -57,13 +67,14 @@ def add_value_labels(ax, spacing=.9, fmt="{0:d}", stacked=False, legend="best"):
             label = ""
 
         # Create annotation
-        ax.annotate(
+        t = ax.annotate(
             label,  # Use `label` as label
             (x_value, y_value),  # Place label at end of the bar
             xytext=(0, space),  # Vertically shift label by `space`
             textcoords="offset points",  # Interpret `xytext` as offset in points
             ha='left',  # Horizontally center label
             va=va)  # Vertically align label differently for
+        t.set_bbox(dict(facecolor='white', alpha=0.2, edgecolor='white',linewidth=0.0))
         # positive and negative values.
 
 
@@ -155,7 +166,7 @@ def matplotlib_lineplot(data, xlabel=None, ylabel=None, title="", xlim=None, yli
 
     when overlapping barplot and lineplot, make sure you add an additional axis, see
     https://stackoverflow.com/questions/42948576/pandas-plot-does-not-overlay
-    
+
     """
     try:
         plt.style.use("macro")
